@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/compose.php,v 2.800.2.125 2009/06/15 22:57:25 jan Exp $
+ * $Horde: imp/compose.php,v 2.800.2.130 2009-12-16 21:56:13 jan Exp $
  *
  * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
@@ -249,6 +249,7 @@ if ($_SESSION['imp']['file_upload']) {
 }
 
 /* Run through the action handlers. */
+$reply_type = null;
 $title = _("New Message");
 switch ($actionID) {
 case 'recompose':
@@ -309,6 +310,9 @@ case 'draft':
             $identity->setDefault($result['identity']);
             $sent_mail_folder = $identity->getValue('sent_mail_folder');
         }
+        if (isset($result['header']['references'])) {
+            $reply_type = 'reply';
+        }
     }
     $get_sig = false;
     break;
@@ -870,7 +874,7 @@ if ($redirect) {
 
     echo $t->fetch(IMP_TEMPLATES . '/compose/redirect.html');
 } else {
-    if (!($reply_type = Util::getFormData('reply_type'))) {
+    if (!($reply_type = Util::getFormData('reply_type', $reply_type))) {
         switch ($actionID) {
         case 'reply':
         case 'reply_all':
@@ -925,7 +929,6 @@ if ($redirect) {
     $t->set('hidden', $hidden);
 
     $t->set('title', htmlspecialchars($title));
-    $t->set('status', IMP::status());
     $t->set('send_msg_ak', Horde::getAccessKeyAndTitle(_("_Send Message")));
     if ($conf['user']['allow_folders']) {
         $t->set('save_draft_ak', Horde::getAccessKeyAndTitle(_("Save _Draft")));
@@ -1116,6 +1119,14 @@ if ($redirect) {
         }
         if (!empty($conf['user']['select_sentmail_folder']) &&
             !$prefs->isLocked('sent_mail_folder')) {
+            /* Check to make sure the sent-mail folder is created - it needs
+             * to exist to show up in drop-down list. */
+            require_once IMP_BASE . '/lib/Folder.php';
+            $imp_folder = &IMP_Folder::singleton();
+            if (!$imp_folder->exists($sent_mail_folder)) {
+                $imp_folder->create($sent_mail_folder, true);
+            }
+
             $t->set('ssm_tabindex', ++$tabindex);
             $t->set('ssm_folders', IMP::flistSelect('', false, array('INBOX'), $sent_mail_folder));
         } else {
@@ -1166,7 +1177,6 @@ if ($redirect) {
         $t->set('attach_vcard', Util::getFormData('vcard'));
     }
     if ($_SESSION['imp']['file_upload']) {
-        $localeinfo = NLS::getLocaleInfo();
         if ($GLOBALS['registry']->hasMethod('files/selectlistLink')) {
             $res = $GLOBALS['registry']->call('files/selectlistLink', array(_("Attach Files"), 'widget', 'compose', true));
             $t->set('selectlistlink', (is_a($res, 'PEAR_Error')) ? null : $res);
@@ -1178,7 +1188,7 @@ if ($redirect) {
                 $t->set('file_tabindex', ++$tabindex);
             }
         }
-        $t->set('attach_size', number_format($imp_compose->maxAttachmentSize(), 0, $localeinfo['decimal_point'], $localeinfo['thousands_sep']));
+        $t->set('attach_size', IMP::numberFormat($imp_compose->maxAttachmentSize(), 0));
         $t->set('help-attachments', Help::link('imp', 'compose-attachments'));
 
         $save_attach = $prefs->getValue('save_attachments');
@@ -1227,15 +1237,16 @@ if ($redirect) {
                 $atc[] = $entry;
             }
             $t->set('atc', $atc);
-            $t->set('total_attach_size', number_format($imp_compose->sizeOfAttachments() / 1024, 2, $localeinfo['decimal_point'], $localeinfo['thousands_sep']));
+            $t->set('total_attach_size', IMP::numberFormat($imp_compose->sizeOfAttachments() / 1024, 2));
             $t->set('perc_attach', ((!empty($conf['compose']['attach_size_limit'])) && ($conf['compose']['attach_size_limit'] > 0)));
             if ($t->get('perc_attach')) {
-                $t->set('perc_attach', sprintf(_("%s%% of allowed size"), number_format($imp_compose->sizeOfAttachments() / $conf['compose']['attach_size_limit'] * 100, 2, $localeinfo['decimal_point'], $localeinfo['thousands_sep'])));
+                $t->set('perc_attach', sprintf(_("%s%% of allowed size"), IMP::numberFormat($imp_compose->sizeOfAttachments() / $conf['compose']['attach_size_limit'] * 100, 2)));
             }
             $t->set('help-current-attachments', Help::link('imp', 'compose-current-attachments'));
         }
     }
 
+    $t->set('status', IMP::status());
     echo $t->fetch(IMP_TEMPLATES . '/compose/compose.html');
 }
 
