@@ -1,7 +1,7 @@
 /**
  * Provides the javascript for the compose.php script.
  *
- * $Horde: imp/js/src/compose.js,v 1.15.2.15 2009/03/30 23:08:41 slusarz Exp $
+ * $Horde: imp/js/src/compose.js,v 1.15.2.16 2010-03-11 06:11:24 slusarz Exp $
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -14,6 +14,7 @@
  */
 
 var display_unload_warning = true,
+    fckedit_event = false,
     textarea_ready = true,
     skip_spellcheck = false;
 
@@ -213,11 +214,6 @@ function uniqSubmit(actionID, event)
     }
 
     if (actionID == 'send_message') {
-        if (($F('subject') == '') &&
-            !window.confirm(IMP.text.compose_nosubject)) {
-            return;
-        }
-
         if (!skip_spellcheck &&
             compose_spellcheck &&
             IMP.SpellCheckerObject &&
@@ -225,6 +221,11 @@ function uniqSubmit(actionID, event)
             IMP.SpellCheckerObject.spellCheck(onNoSpellError.curry(actionID, event));
             return;
         }
+
+        if (($F('subject') == '') &&
+            !window.confirm(IMP.text.compose_nosubject)) {
+            return;
+        }
     }
 
     skip_spellcheck = false;
@@ -254,6 +255,7 @@ function _uniqSubmit()
 function onNoSpellError(actionID, e)
 {
     skip_spellcheck = true;
+    textarea_ready = true;
     uniqSubmit(actionID, e);
 }
 
@@ -332,8 +334,11 @@ function initializeSpellChecker()
 
         case 'fckeditor':
             ed = FCKeditorAPI.GetInstance('message');
+            if (!this.fckedit_event) {
+                ed.Events.AttachEvent('OnAfterSetHTML', function() { textarea_ready = true; });
+                this.fckedit_event = true;
+            }
             ed.SetHTML($('message').value);
-            ed.Events.AttachEvent('OnAfterSetHTML', function() { textarea_ready = true; });
             break;
         }
     }
