@@ -3,17 +3,15 @@
  * The IMP_Fetchmail_imap driver implements the IMAP_Fetchmail class for use
  * with IMAP/POP3 servers.
  *
- * $Horde: imp/lib/Fetchmail/imap.php,v 1.5.10.10 2007/05/12 16:32:53 chuck Exp $
+ * $Horde: imp/lib/Fetchmail/imap.php,v 1.5.10.14 2009-01-06 15:24:05 jan Exp $
  *
- * Copyright 2002-2007 Nuno Loureiro <nuno@co.sapo.pt>
- * Copyright 2004-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Nuno Loureiro <nuno@co.sapo.pt>
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   IMP 4.0
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package IMP
  */
 class IMP_Fetchmail_imap extends IMP_Fetchmail {
@@ -88,64 +86,17 @@ class IMP_Fetchmail_imap extends IMP_Fetchmail {
      */
     function _protocolList()
     {
-        return array(
-            'pop3auto' => array(
+        return array_merge(
+            IMP_IMAP::protocolList(),
+            array('pop3auto' => array(
                 'name' => _("POP3 (Auto Detect Protocols)"),
-                'auto' => array('pop3', 'pop3notls', 'pop3sslvalid', 'pop3ssl'),
-                'base' => 'POP3'
+                'auto' => array('pop3', 'pop3tls', 'pop3notls', 'pop3sslvalid', 'pop3ssl'),
+                'base' => 'POP3')
             ),
-            'pop3' => array(
-                'name' => _("POP3"),
-                'string' => 'pop3',
-                'port' => 110,
-                'base' => 'POP3'
-            ),
-            'pop3notls' => array(
-                'name' => _("POP3, no TLS"),
-                'string' => 'pop3/notls',
-                'port' => 110,
-                'base' => 'POP3'
-            ),
-            'pop3sslvalid' => array(
-                'name' => _("POP3 over SSL"),
-                'string' => 'pop3/ssl',
-                'port' => 995,
-                'base' => 'POP3'
-            ),
-            'pop3ssl' => array(
-                'name' => _("POP3 over SSL (self-signed certificate)"),
-                'string' => 'pop3/ssl/novalidate-cert',
-                'port' => 995,
-                'base' => 'POP3'
-            ),
-            'imapauto' => array(
+            array('imapauto' => array(
                 'name' => _("IMAP (Auto Detect Protocols)"),
-                'auto' => array('imap', 'imapnotls', 'imapsslvalid', 'imapssl'),
-                'base' => 'IMAP'
-            ),
-            'imap' => array(
-                'name' => _("IMAP"),
-                'string' => 'imap',
-                'port' => 143,
-                'base' => 'IMAP'
-            ),
-            'imapnotls' => array(
-                'name' => _("IMAP, no TLS"),
-                'string' => 'imap/notls',
-                'port' => 143,
-                'base' => 'IMAP'
-            ),
-            'imapsslvalid' => array(
-                'name' => _("IMAP over SSL"),
-                'string' => 'imap/ssl',
-                'port' => 993,
-                'base' => 'IMAP'
-            ),
-            'imapssl' => array(
-                'name' => _("IMAP over SSL (self-signed certificate)"),
-                'string' => 'imap/ssl/novalidate-cert',
-                'port' => 993,
-                'base' => 'IMAP'
+                'auto' => array('imap', 'imaptls', 'imapnotls', 'imapsslvalid', 'imapssl'),
+                'base' => 'IMAP')
             )
         );
     }
@@ -170,7 +121,7 @@ class IMP_Fetchmail_imap extends IMP_Fetchmail {
             return true;
         }
 
-        return (bool) @imap_list($stream, $this->_serverstring, $this->_params['rmailbox']);
+        return (bool)@imap_list($stream, $this->_serverstring, $this->_params['rmailbox']);
     }
 
     /**
