@@ -3,15 +3,14 @@
  * The IMP_MIME_Viewer_partial class allows multipart/partial messages to be
  * displayed (RFC 2046 [5.2.2]).
  *
- * $Horde: imp/lib/MIME/Viewer/partial.php,v 1.17.10.11 2007/01/02 13:55:00 jan Exp $
+ * $Horde: imp/lib/MIME/Viewer/partial.php,v 1.17.10.14 2009-01-06 15:24:09 jan Exp $
  *
- * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   IMP 4.0
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde_MIME_Viewer
  */
 class IMP_MIME_Viewer_partial extends MIME_Viewer {
@@ -28,8 +27,6 @@ class IMP_MIME_Viewer_partial extends MIME_Viewer {
     {
         $contents = &$params[0];
 
-        global $imp;
-
         $base_ob = &$contents->getBaseObjectPtr();
         $curr_index = $base_ob->getMessageIndex();
         $id = $this->mime_part->getContentTypeParameter('id');
@@ -40,10 +37,10 @@ class IMP_MIME_Viewer_partial extends MIME_Viewer {
         require_once 'Horde/MIME/Structure.php';
 
         /* Perform the search to find the other parts of the message. */
-        $imap_search = &IMP_IMAP_Search::singleton(array('pop3' => ($imp['base_protocol'] == 'pop3')));
-        $query = &new IMP_IMAP_Search_Query();
+        $imap_search = &IMP_IMAP_Search::singleton(array('pop3' => ($_SESSION['imp']['base_protocol'] == 'pop3')));
+        $query = new IMP_IMAP_Search_Query();
         $query->header('Content-Type', $id);
-        $indices = $imap_search->searchMailbox($query, $imp['stream'], IMP::serverString($imp['mailbox']));
+        $indices = $imap_search->searchMailbox($query, null, $GLOBALS['imp_mbox']['thismailbox']);
 
         /* If not able to find the other parts of the message, print error. */
         if (count($indices) != $this->mime_part->getContentTypeParameter('total')) {
@@ -58,7 +55,7 @@ class IMP_MIME_Viewer_partial extends MIME_Viewer {
             } else {
                 require_once IMP_BASE . '/lib/MIME/Contents.php';
                 require_once IMP_BASE . '/lib/MIME/Headers.php';
-                $imp_contents = &IMP_Contents::singleton($val . IMP_IDX_SEP . $_SESSION['imp']['thismailbox']);
+                $imp_contents = &IMP_Contents::singleton($val . IMP_IDX_SEP . $GLOBALS['imp_mbox']['thismailbox']);
                 $part = &$imp_contents->getMIMEPart(0);
                 $parts[$part->getContentTypeParameter('number')] = $imp_contents->getBody();
             }
@@ -69,7 +66,7 @@ class IMP_MIME_Viewer_partial extends MIME_Viewer {
 
         /* Combine the parts and render the underlying data. */
         $mime_message = &MIME_Structure::parseTextMIMEMessage(implode('', $parts));
-        $mc = &new MIME_Contents($mime_message, array('download' => 'download_attach', 'view' => 'view_attach'), array(&$contents));
+        $mc = new MIME_Contents($mime_message, array('download' => 'download_attach', 'view' => 'view_attach'), array(&$contents));
         $mc->buildMessage();
 
         return '<table>' . $mc->getMessage(true) . '</table>';
