@@ -3,15 +3,14 @@
  * Maintenance module that presents a TOS Agreement page to user.
  * If user does not accept terms, user is not allowed to login.
  *
- * $Horde: imp/lib/Maintenance/Task/tos_agreement.php,v 1.11.10.8 2007/01/02 13:55:01 jan Exp $
+ * $Horde: imp/lib/Maintenance/Task/tos_agreement.php,v 1.11.10.11 2009-01-06 15:24:10 jan Exp $
  *
- * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   IMP 4.0
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde_Maintenance
  */
 class Maintenance_Task_tos_agreement extends Maintenance_Task {
@@ -31,8 +30,8 @@ class Maintenance_Task_tos_agreement extends Maintenance_Task {
     {
         $result = Util::getFormData('not_agree');
         if (isset($result)) {
-           header('Location: ' . Auth::addLogoutParameters(IMP::logoutUrl(), AUTH_REASON_MESSAGE, _("You did not agree to the Terms of Service agreement, so you were not allowed to login.")));
-           exit;
+            header('Location: ' . Auth::addLogoutParameters(IMP::logoutUrl(), AUTH_REASON_MESSAGE, _("You did not agree to the Terms of Service agreement, so you were not allowed to login.")));
+            exit;
         }
     }
 
@@ -43,13 +42,11 @@ class Maintenance_Task_tos_agreement extends Maintenance_Task {
      */
     function describeMaintenance()
     {
-        global $conf;
-
-        if (empty($conf['tos']['file'])) {
+        if (empty($GLOBALS['conf']['tos']['file'])) {
             Horde::fatal(PEAR::raiseError(sprintf(_("Terms of Service file not specified in conf.php"))), __FILE__, __LINE__);
         }
 
-        return file_get_contents($conf['tos']['file']);
+        return file_get_contents($GLOBALS['conf']['tos']['file']);
     }
 
 }
