@@ -15,30 +15,21 @@ define('IMP_MESSAGE_COPY', 2);
  * For any function below that requires an $indices parameter, see
  * IMP::parseIndicesList() for the list of allowable inputs.
  *
- * $Horde: imp/lib/Message.php,v 1.164.8.49 2007/07/03 14:56:26 slusarz Exp $
+ * $Horde: imp/lib/Message.php,v 1.164.8.64 2010-09-01 07:57:47 slusarz Exp $
  *
- * Copyright 2000-2007 Chris Hyde <chris@jeks.net>
- * Copyright 2000-2007 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2000-2001 Chris Hyde <chris@jeks.net>
+ * Copyright 2000-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Chris Hyde <chris@jeks.net>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   IMP 2.3
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package IMP
  */
 class IMP_Message {
 
-    /**
-     * The IMP_IMAP object for the current server.
-     *
-     * @var IMP_IMAP
-     */
-    var $_impImap;
-
     /**
      * Using POP to access mailboxes?
      *
@@ -46,6 +37,20 @@ class IMP_Message {
      */
     var $_usepop = false;
 
+    /**
+     * The active IMP_Mailbox object to update on certain actions
+     *
+     * @var IMP_Mailbox
+     */
+    var $_mboxOb;
+
+    /**
+     * Recursion count used to determine when $_mboxOb should be unset.
+     *
+     * @var integer
+     */
+    var $_mboxObCount = 0;
+
     /**
      * Returns a reference to the global IMP_Message object, only creating it
      * if it doesn't already exist. This ensures that only one IMP_Message
@@ -73,12 +78,9 @@ class IMP_Message {
      */
     function IMP_Message()
     {
-        if ($GLOBALS['imp']['base_protocol'] == 'pop3') {
+        if ($_SESSION['imp']['base_protocol'] == 'pop3') {
             $this->_usepop = true;
         }
-
-        require_once IMP_BASE . '/lib/IMAP.php';
-        $this->_impImap = &IMP_IMAP::singleton();
     }
 
     /**
@@ -88,57 +90,81 @@ class IMP_Message {
      * @param string $targetMbox  The mailbox to move/copy messages to.
      * @param integer $action     Either IMP_MESSAGE_MOVE or IMP_MESSAGE_COPY.
      * @param mixed &$indices     See above.
+     * @param boolean $new        Whether the target mailbox has to be created.
      *
      * @return boolean  True if successful, false if not.
      */
-    function copy($targetMbox, $action, &$indices)
+    function copy($targetMbox, $action, &$indices, $new = false)
     {
-        global $imp, $notification, $prefs;
+        global $conf, $notification, $prefs;
+
+        if ($conf['tasklist']['use_tasklist'] &&
+            (strpos($targetMbox, '_tasklist_') === 0)) {
+            /* If the target is a tasklist, handle the move/copy specially. */
+            $tasklist = str_replace('_tasklist_', '', $targetMbox);
+            return $this->createTasksOrNotes($tasklist, $action, $indices, 'task');
+        }
+        if ($conf['notepad']['use_notepad'] &&
+            (strpos($targetMbox, '_notepad_') === 0)) {
+            /* If the target is a notepad, handle the move/copy specially. */
+            $notepad = str_replace('_notepad_', '', $targetMbox);
+            return $this->createTasksOrNotes($notepad, $action, $indices, 'note');
+        }
 
         if (!($msgList = IMP::parseIndicesList($indices))) {
             return false;
         }
+        $this->_mboxOb = &$indices;
+        ++$this->_mboxObCount;
+
+        if ($new) {
+            require_once IMP_BASE . '/lib/Folder.php';
+            $imp_folder = &IMP_Folder::singleton();
+            if (!$imp_folder->exists($targetMbox) &&
+                !$imp_folder->create($targetMbox, $prefs->getValue('subscribe'))) {
+                return false;
+            }
+        }
+
+        $expunge_list = array();
+        $imap_flags = CP_UID;
+        $return_value = true;
 
         switch ($action) {
         case IMP_MESSAGE_MOVE:
-            $imap_flags = CP_UID | CP_MOVE;
+            $imap_flags |= CP_MOVE;
             $message = _("There was an error moving messages from \"%s\" to \"%s\". This is what the server said");
             break;
 
         case IMP_MESSAGE_COPY:
-            $imap_flags = CP_UID;
             $message = _("There was an error copying messages from \"%s\" to \"%s\". This is what the server said");
             break;
         }
 
-        $return_value = true;
+        require_once IMP_BASE . '/lib/IMAP/Cache.php';
+        $imap_cache = &IMP_IMAP_Cache::singleton();
+        $imp_imap = &IMP_IMAP::singleton();
 
         foreach ($msgList as $folder => $msgIndices) {
             $msgIdxString = implode(',', $msgIndices);
 
-            /* Switch folders, if necessary (only valid for IMAP). */
-            $this->_impImap->changeMbox($folder);
+            /* Switch folders. */
+            $imp_imap->changeMbox($folder, ($action == IMP_MESSAGE_MOVE) ? IMP_IMAP_READWRITE : IMP_IMAP_AUTO);
 
             /* Attempt to copy/move messages to new mailbox. */
-            if (!@imap_mail_copy($imp['stream'], $msgIdxString, $targetMbox, $imap_flags)) {
+            if (!@imap_mail_copy($imp_imap->stream(), $msgIdxString, $targetMbox, $imap_flags)) {
                 $notification->push(sprintf($message, IMP::displayFolder($folder), IMP::displayFolder($targetMbox)) . ': ' . imap_last_error(), 'horde.error');
                 $return_value = false;
-            }
-
-            /* If moving, and using the trash, expunge immediately. */
-            if ($prefs->getValue('use_trash') &&
-                ($action == IMP_MESSAGE_MOVE)) {
-                @imap_expunge($imp['stream']);
+            } elseif ($action == IMP_MESSAGE_MOVE) {
+                $imap_cache->expireCache($folder, 2 | 4);
+                $expunge_list[$folder] = $msgIndices;
             }
         }
 
-        /* Update the mailbox. */
-        if (is_a($indices, 'IMP_Mailbox')) {
-            if ($action == IMP_MESSAGE_COPY) {
-                $indices->updateMailbox(IMP_MAILBOX_COPY, $return_value);
-            } else {
-                $indices->updateMailbox(IMP_MAILBOX_MOVE, $return_value);
-            }
+        $imap_cache->expireCache($targetMbox, 2 | 4);
+        $this->expungeMailbox($expunge_list);
+        if (!(--$this->_mboxObCount)) {
+            unset($this->_mboxOb);
         }
 
         return $return_value;
@@ -155,11 +181,12 @@ class IMP_Message {
      * @param boolean $keeplog  Should any history information of the
      *                          message be kept?
      *
-     * @return boolean  True if successful, false if not.
+     * @return integer|boolean  The number of messages deleted if successful,
+     *                          false if not.
      */
     function delete(&$indices, $nuke = false, $keeplog = false)
     {
-        global $conf, $imp, $notification, $prefs;
+        global $conf, $notification, $prefs;
 
         if (!($msgList = IMP::parseIndicesList($indices))) {
             return false;
@@ -167,21 +194,28 @@ class IMP_Message {
 
         $trash = IMP::folderPref($prefs->getValue('trash_folder'), true);
         $use_trash = $prefs->getValue('use_trash');
-        if ($use_trash && !$trash) {
-            $notification->push(_("Can not move messages to Trash - no Trash mailbox set in preferences."), 'horde.error');
+        $use_vtrash = $prefs->getValue('use_vtrash');
+        if ($use_trash && !$use_vtrash && empty($trash)) {
+            $notification->push(_("Cannot move messages to Trash - no Trash mailbox set in preferences."), 'horde.error');
             return false;
         }
 
-        $return_value = true;
-        $use_vtrash = $prefs->getValue('use_vtrash');
+        $return_value = 0;
         $maillog_update = (!$keeplog && !empty($conf['maillog']['use_maillog']));
 
-        /* If the folder we are deleting from has changed. */
-        foreach ($msgList as $folder => $msgIndices) {
-            $sequence = implode(',', $msgIndices);
+        $imp_imap = &IMP_IMAP::singleton();
+        $stream = $imp_imap->stream();
 
-            /* Switch folders, if necessary (only valid for IMAP). */
-            $this->_impImap->changeMbox($folder);
+        $this->_mboxOb = &$indices;
+        ++$this->_mboxObCount;
+
+        foreach ($msgList as $folder => $msgIndices) {
+            $indices_array = array($folder => $msgIndices);
+            $sequence = implode(',', $msgIndices);
+            $return_value += count($msgIndices);
+
+            /* Switch folders, if necessary. */
+            $imp_imap->changeMbox($folder);
 
             /* Trash is only valid for IMAP mailboxes. */
             if (!$this->_usepop &&
@@ -196,11 +230,14 @@ class IMP_Message {
 
                 if (!$imp_folder->exists($trash)) {
                     if (!$imp_folder->create($trash, $prefs->getValue('subscribe'))) {
+                        if (!(--$this->_mboxObCount)) {
+                            unset($this->_mboxOb);
+                        }
                         return false;
                     }
                 }
 
-                if (!@imap_mail_move($imp['stream'], $sequence, $trash, CP_UID)) {
+                if (!@imap_mail_move($stream, $sequence, $trash, CP_UID)) {
                     $error_msg = imap_last_error();
                     $error = true;
 
@@ -215,14 +252,14 @@ class IMP_Message {
 
                         /* Get text of deleted messages. */
                         foreach ($msgIndices as $val) {
-                            $msg_text[] = imap_fetchheader($imp['stream'], $val, FT_UID | FT_PREFETCHTEXT) . imap_body($imp['stream'], $val, FT_UID);
+                            $msg_text[] = imap_fetchheader($stream, $val, FT_UID | FT_PREFETCHTEXT) . imap_body($stream, $val, FT_UID);
                         }
-                        @imap_delete($imp['stream'], $sequence, FT_UID);
-                        @imap_expunge($imp['stream']);
+                        @imap_delete($stream, $sequence, FT_UID);
+                        $this->expungeMailbox($indices_array);
 
                         /* Save messages in Trash folder. */
                         foreach ($msg_text as $val) {
-                            if (!@imap_append($imp['stream'], IMP::serverString($trash), $val)) {
+                            if (!@imap_append($stream, IMP::serverString($trash), $val)) {
                                 $error = true;
                                 break;
                             }
@@ -234,62 +271,55 @@ class IMP_Message {
                         $return_value = false;
                     }
                 } else {
-                    @imap_expunge($imp['stream']);
+                    $this->expungeMailbox($indices_array);
                 }
             } else {
                 /* Get the list of Message-IDs for the deleted messages if
                  * using maillogging. */
                 if ($maillog_update) {
-                    $overview = @imap_fetch_overview($imp['stream'], $sequence, FT_UID);
+                    if (!isset($msg_cache)) {
+                        require_once IMP_BASE . '/lib/IMAP/MessageCache.php';
+                        $msg_cache = &IMP_MessageCache::singleton();
+                    }
+                    $overview = $msg_cache->retrieve($folder, $msgIndices, 1);
                 }
 
                 /* Delete the messages. */
-                if (!@imap_delete($imp['stream'], $sequence, FT_UID)) {
-                    if ($this->_usepop) {
-                        $notification->push(sprintf(_("There was an error deleting messages. This is what the server said: %s"), imap_last_error()), 'horde.error');
-                    } else {
-                        $notification->push(sprintf(_("There was an error deleting messages from the folder \"%s\". This is what the server said"), IMP::displayFolder($folder)) . ': ' . imap_last_error(), 'horde.error');
-                    }
-                    $return_value = false;
+                if ($this->_usepop ||
+                    $nuke ||
+                    ($use_trash && ($folder == $trash)) ||
+                    ($use_vtrash && ($GLOBALS['imp_search']->isVTrashFolder()))) {
+                    /* Purge messages immediately. */
+                    @imap_delete($stream, $sequence, FT_UID);
+                    $this->expungeMailbox($indices_array);
                 } else {
-                    $delIndices = array($folder => $msgIndices);
-                    $flag_str = '\\DELETED';
+                    /* If we are using virtual trash, we must mark the message
+                     * as seen or else it will appear as an 'unseen' message
+                     * for purposes of new message counts. */
+                    $del_flags = array('deleted');
+                    if ($use_vtrash) {
+                        $del_flags[] = 'seen';
+                    }
+                    $this->flag($del_flags, $indices_array);
+                }
 
-                    if ($this->_usepop ||
-                        $nuke ||
-                        ($use_trash && ($folder == $trash))) {
-                        /* Purge messages in the trash folder immediately. */
-                        $this->flag($flag_str, $delIndices);
-                        @imap_expunge($imp['stream']);
-                    } else {
-                        /* If we are using vitrual trash, we must mark the 
-                         * message as seen or else it will appear as an
-                         * 'unseen' message for purposes of new message
-                         * counts. */
-                        if ($use_vtrash) {
-                            $this->flag($flag_str . ' \\SEEN', $delIndices);
+                /* Get the list of Message-IDs deleted, and remove
+                 * the information from the mail log. */
+                if ($maillog_update) {
+                    $msg_ids = array();
+                    foreach ($overview as $val) {
+                        if (!empty($val->message_id)) {
+                            $msg_ids[] = $val->message_id;
                         }
                     }
-
-                    /* Get the list of Message-IDs deleted, and remove
-                     * the information from the mail log. */
-                    if ($maillog_update) {
-                        $msg_ids = array();
-                        foreach ($overview as $val) {
-                            if (!empty($val->message_id)) {
-                                $msg_ids[] = $val->message_id;
-                            }
-                        }
-                        require_once IMP_BASE . '/lib/Maillog.php';
-                        IMP_Maillog::deleteLog($msg_ids);
-                    }
+                    require_once IMP_BASE . '/lib/Maillog.php';
+                    IMP_Maillog::deleteLog($msg_ids);
                 }
             }
         }
 
-        /* Update the mailbox. */
-        if (is_a($indices, 'IMP_Mailbox')) {
-            $indices->updateMailbox(IMP_MAILBOX_DELETE, $return_value);
+        if (!(--$this->_mboxObCount)) {
+            unset($this->_mboxOb);
         }
 
         return $return_value;
@@ -306,33 +336,7 @@ class IMP_Message {
      */
     function undelete(&$indices)
     {
-        global $imp, $notification;
-
-        if (!($msgList = IMP::parseIndicesList($indices))) {
-            return false;
-        }
-
-        $return_value = true;
-
-        foreach ($msgList as $folder => $msgIndices) {
-            $msgIdxString = implode(',', $msgIndices);
-
-            /* Switch folders, if necessary. */
-            $this->_impImap->changeMbox($folder);
-
-            if ($imp['stream'] &&
-                !@imap_undelete($imp['stream'], $msgIdxString, FT_UID)) {
-                $notification->push(sprintf(_("There was an error deleting messages in the folder \"%s\". This is what the server said"), IMP::displayFolder($folder)) . ': ' . imap_last_error(), 'horde.error');
-                $return_value = false;
-            }
-        }
-
-        /* Update the mailbox. */
-        if (is_a($indices, 'IMP_Mailbox')) {
-            $indices->updateMailbox(IMP_MAILBOX_UNDELETE, $return_value);
-        }
-
-        return $return_value;
+        return $this->flag(array('deleted'), $indices, false);
     }
 
     /**
@@ -357,29 +361,27 @@ class IMP_Message {
 
         require_once IMP_BASE . '/lib/Compose.php';
         require_once IMP_BASE . '/lib/MIME/Contents.php';
-        require_once IMP_BASE . '/lib/MIME/Headers.php';
         require_once 'Text/Flowed.php';
         require_once 'Horde/iCalendar.php';
 
         foreach ($msgList as $folder => $msgIndices) {
             foreach ($msgIndices as $index) {
-                /* Fetch the message headers. */
-                $imp_headers = &new IMP_Headers($index);
-                $imp_headers->buildHeaders();
-                $subject = $imp_headers->getValue('subject');
-
                 /* Fetch the message contents. */
                 $imp_contents = &IMP_Contents::singleton($index . IMP_IDX_SEP . $folder);
                 $imp_contents->buildMessage();
 
+                /* Fetch the message headers. */
+                $imp_headers = &$imp_contents->getHeaderOb();
+                $subject = $imp_headers->getValue('subject');
+
                 /* Extract the message body. */
-                $imp_compose = &new IMP_Compose();
+                $imp_compose = &IMP_Compose::singleton();
                 $mime_message = $imp_contents->getMIMEMessage();
                 $body_id = $imp_compose->getBodyId($imp_contents);
                 $body = $imp_compose->findBody($imp_contents);
 
                 /* Re-flow the message for prettier formatting. */
-                $flowed = &new Text_Flowed($mime_message->replaceEOL($body, "\n"));
+                $flowed = new Text_Flowed($mime_message->replaceEOL($body, "\n"));
                 if (($mime_message->getContentTypeParameter('delsp') == 'yes') &&
                     method_exists($flowed, 'setDelSp')) {
                     $flowed->setDelSp(true);
@@ -394,7 +396,7 @@ class IMP_Message {
                 $body = String::convertCharset($body, $body_part->getCharset(), NLS::getCharset());
 
                 /* Create a new iCalendar. */
-                $vCal = &new Horde_iCalendar();
+                $vCal = new Horde_iCalendar();
                 $vCal->setAttribute('PRODID', '-//The Horde Project//IMP ' . IMP_VERSION . '//EN');
                 $vCal->setAttribute('METHOD', 'PUBLISH');
 
@@ -414,7 +416,7 @@ class IMP_Message {
                     /* Attempt to add the new vTodo item to the requested
                      * tasklist. */
                     $res = $registry->call('tasks/import',
-                                           array($vTodo, 'text/x-vtodo', $list));
+                                           array($vTodo, 'text/calendar', $list));
                     break;
 
                 case 'note':
@@ -479,20 +481,20 @@ class IMP_Message {
     }
 
     /**
-     * Strips a MIME Part out of a message.
+     * Strips one or all MIME parts out of a message.
+     *
      * Handles the IMP_SEARCH_MBOX mailbox.
      *
-     * @param IMP_Mailbox &$imp_mailbox  The IMP_Mailbox object with the
-     *                                   current index set to the message to be
-     *                                   processed.
-     * @param string $partid             The MIME ID of the part to strip.
+     * @param IMP_Mailbox $imp_mailbox  The IMP_Mailbox object with the
+     *                                  current index set to the message to be
+     *                                  processed.
+     * @param string $partid            The MIME ID of the part to strip. All
+     *                                  parts are stripped if null.
      *
      * @return boolean  Returns true on success, or PEAR_Error on error.
      */
-    function stripPart(&$imp_mailbox, $partid)
+    function stripPart(&$imp_mailbox, $partid = null)
     {
-        global $imp;
-
         /* Return error if no index was provided. */
         if (!($msgList = IMP::parseIndicesList($imp_mailbox))) {
             return PEAR::raiseError('No index provided to IMP_Message::stripPart().');
@@ -508,51 +510,71 @@ class IMP_Message {
 
         require_once 'Horde/MIME/Part.php';
         require_once IMP_BASE . '/lib/MIME/Contents.php';
-        require_once IMP_BASE . '/lib/MIME/Headers.php';
+        require_once IMP_BASE . '/lib/IMAP/MessageCache.php';
 
-        /* Get a local copy of the message and strip out the desired
-           MIME_Part object. */
+        /* Get a local copy of the message. */
         $contents = &IMP_Contents::singleton($index . IMP_IDX_SEP . $folder);
         $contents->rebuildMessage();
         $message = $contents->getMIMEMessage();
-        $oldPart = $message->getPart($partid);
-        $newPart = new MIME_Part('text/plain');
 
-        /* We need to make sure all text is in the correct charset. */
-        $newPart->setCharset(NLS::getCharset());
-        $newPart->setContents(sprintf(_("[Attachment stripped: Original attachment type: %s, name: %s]"), $oldPart->getType(), $oldPart->getName(true, true)), '8bit');
-        $message->alterPart($partid, $newPart);
+        /* Loop through all to-be-stripped mime parts. */
+        if (is_null($partid)) {
+            $partids = $contents->getDownloadAllList();
+        } else {
+            $partids = array($partid);
+        }
+        foreach ($partids as $partid) {
+            $oldPart = $message->getPart($partid);
+            if (!is_a($oldPart, 'MIME_Part')) {
+                continue;
+            }
+            $newPart = new MIME_Part('text/plain');
+
+            /* We need to make sure all text is in the correct charset. */
+            $newPart->setCharset(NLS::getCharset());
+            $newPart->setContents(sprintf(_("[Attachment stripped: Original attachment type: %s, name: %s]"), $oldPart->getType(), $oldPart->getName(true, true)), '8bit');
+            $newPart->setDisposition('attachment');
+            $message->alterPart($partid, $newPart);
+        }
 
         /* We need to make sure we add "\r\n" after every line for
-           imap_append() - some servers require it (e.g. Cyrus). */
+         * imap_append() - some servers require it (e.g. Cyrus). */
         $message->setEOL(MIME_PART_RFC_EOL);
 
         /* Get the headers for the message. */
-        $headers = &new IMP_Headers($index);
-        $headers->buildFlags();
+        $msg_cache = &IMP_MessageCache::singleton();
+        $cache_ob = $msg_cache->retrieve($folder, array($index), 1 | 32);
+        $ob = reset($cache_ob);
         $flags = array();
+        /* If in Virtual Inbox, we need to reset flag to unseen so that it
+         * appears again in the mailbox list. */
+        $vinbox = $GLOBALS['imp_search']->isVINBOXFolder($imp_mailbox->getMailboxName());
         foreach (array('answered', 'deleted', 'draft', 'flagged', 'seen') as $flag) {
-            if ($headers->getFlag($flag)) {
+            if ($ob->$flag && (!$vinbox || ($flag != 'seen'))) {
                 $flags[] = '\\' . $flag;
             }
         }
         $flags = implode(' ', $flags);
 
-        /* This is a (sort-of) hack. Right before we append the new message
-           we check imap_status() to determine the next available UID. We
-           use this UID as the new index of the message. */
-        $folderstring = IMP::serverString($folder);
-        $headerstring = $headers->getHeaderText();
-        $this->_impImap->changeMbox($folder);
-        $status = @imap_status($imp['stream'], $folderstring, SA_UIDNEXT);
-        if (@imap_append($imp['stream'], $folderstring, $headerstring . $contents->toString($message, true), $flags)) {
+        $imp_imap = &IMP_IMAP::singleton();
+        $imp_imap->changeMbox($folder);
+        $folder = IMP::serverString($folder);
+        if (@imap_append($imp_imap->stream(), $folder, $ob->header->getHeaderText() . $contents->toString($message, true), $flags)) {
             $this->delete($imp_mailbox, true, true);
             $imp_mailbox->updateMailbox(IMP_MAILBOX_UPDATE);
-            $imp_mailbox->setNewIndex($status->uidnext);
+
+            /* Search for the most recent message in the current mailbox with
+             * the old Message-ID - this is the IMAP UID of the saved
+             * message. */
+            require_once IMP_BASE . '/lib/IMAP/Search.php';
+            $query = new IMP_IMAP_Search_Query();
+            $query->header('Message-ID', $ob->header->getValue('message-id'));
+            $ids = $GLOBALS['imp_search']->runSearchQuery($query, $folder, SORTARRIVAL, 1);
+            $imp_mailbox->setIndex($ids[0]);
 
             /* We need to replace the old index in the query string with the
                new index. */
-            $_SERVER['QUERY_STRING'] = preg_replace('/' . $index . '/', $status->uidnext, $_SERVER['QUERY_STRING']);
+            $_SERVER['QUERY_STRING'] = preg_replace('/' . $index . '/', $ids[0], $_SERVER['QUERY_STRING']);
 
             return true;
         } else {
@@ -566,13 +588,9 @@ class IMP_Message {
      * This function works with IMAP only, not POP3.
      *
      * Valid flags are:
-     *   \\SEEN
-     *   \\FLAGGED
-     *   \\ANSWERED
-     *   \\DELETED
-     *   \\DRAFT
+     *   'seen', 'flagged', 'answered', 'deleted', 'draft'
      *
-     * @param string $flag     The IMAP flag(s) to set or clear.
+     * @param array $flag      The IMAP flag(s) to set or clear.
      * @param mixed &$indices  See above.
      * @param boolean $action  If true, set the flag(s), otherwise clear the
      *                         flag(s).
@@ -584,24 +602,52 @@ class IMP_Message {
         if (!($msgList = IMP::parseIndicesList($indices))) {
             return false;
         }
+        $this->_mboxOb = &$indices;
+        ++$this->_mboxObCount;
 
         $function = ($action) ? 'imap_setflag_full' : 'imap_clearflag_full';
-        $return_value = true;
+        $update_list = array();
+
+        require_once IMP_BASE . '/lib/IMAP/MessageCache.php';
+        $msg_cache = &IMP_MessageCache::singleton();
+
+        $imp_imap = &IMP_IMAP::singleton();
 
         foreach ($msgList as $folder => $msgIndices) {
             $msgIdxString = implode(',', $msgIndices);
 
             /* Switch folders, if necessary. */
-            $this->_impImap->changeMbox($folder);
+            $imp_imap->changeMbox($folder);
+
+            $del_flag = false;
+            $flag_str = '';
+            foreach ($flag as $val) {
+                $flag_val = String::upper($val);
+                $flag_str .= " \\" . $flag_val;
+                if ($flag_val == 'DELETED') {
+                    $del_flag = true;
+                }
+            }
 
             /* Flag/unflag the messages now. */
-            if (!call_user_func($function, $GLOBALS['imp']['stream'], $msgIdxString, $flag, ST_UID)) {
+            if (!call_user_func($function, $imp_imap->stream(), $msgIdxString, ltrim($flag_str), ST_UID)) {
                 $GLOBALS['notification']->push(sprintf(_("There was an error flagging messages in the folder \"%s\". This is what the server said"), IMP::displayFolder($folder)) . ': ' . imap_last_error(), 'horde.error');
-                $return_value = false;
+            } else {
+                if ($action && $del_flag) {
+                    $this->_updateMailbox(array($folder => $msgIndices), 'delete');
+                }
+                $msg_cache->updateFlags($folder, $msgIndices, $flag, $action);
+                $update_list[$folder] = $msgIndices;
             }
         }
 
-        return $return_value;
+        /* Update the mailbox. */
+        $this->_updateMailbox($update_list, 'flag');
+        if (!(--$this->_mboxObCount)) {
+            unset($this->_mboxOb);
+        }
+
+        return (!empty($update_list));
     }
 
     /**
@@ -610,7 +656,7 @@ class IMP_Message {
      *
      * See flag() for the list of valid flags.
      *
-     * @param string $flag     The IMAP flag(s) to set or clear.
+     * @param array $flag      The IMAP flag(s) to set or clear.
      * @param array $mboxes    The list of mailboxes to flag.
      * @param boolean $action  If true, set the flag(s), otherwise, clear the
      *                         flag(s).
@@ -625,14 +671,17 @@ class IMP_Message {
 
         $return_value = true;
 
+        require_once IMP_BASE . '/lib/IMAP/Cache.php';
+        $imap_cache = &IMP_IMAP_Cache::singleton();
+
         foreach ($mboxes as $val) {
-            /* Switch folders, if necessary. */
-            $this->_impImap->changeMbox($val);
-            if ($uids = @imap_search($GLOBALS['imp']['stream'], 'ALL', SE_UID)) {
+            if ($uids = $imap_cache->getMailboxArrival($val)) {
                 $indices = array($val => $uids);
                 if (!$this->flag($flag, $indices, $action)) {
                     $return_value = false;
                 }
+            } else {
+                $return_value = false;
             }
         }
 
@@ -642,24 +691,72 @@ class IMP_Message {
     /**
      * Expunges all deleted messages from the list of mailboxes.
      *
-     * @param array $mbox_list  The list of mailboxes to empty.
+     * @param array $mbox_list  The list of mailboxes to empty as keys; an
+     *                          optional array of indices to delete as values.
+     *                          If the value is not an array, all messages
+     *                          flagged as deleted in the mailbox will be
+     *                          deleted.
+     *
+     * @return array  An array of mailbox names as keys and UIDS as values
+     *                that were expunged.
      */
     function expungeMailbox($mbox_list)
     {
-        global $imp;
+        if (empty($mbox_list)) {
+            return array();
+        }
 
-        foreach ($mbox_list as $val) {
-            if ($GLOBALS['imp_search']->isSearchMbox($val)) {
-                foreach ($GLOBALS['imp_search']->getSearchFolders($val) as $folder) {
-                    $stream = $this->_impImap->openIMAPStream($folder);
-                    @imap_expunge($stream);
-                    @imap_close($stream);
+        $process_list = $update_list = array();
+
+        require_once IMP_BASE . '/lib/IMAP/MessageCache.php';
+        $msg_cache = &IMP_MessageCache::singleton();
+
+        $imp_imap = &IMP_IMAP::singleton();
+        $stream = $imp_imap->stream();
+
+        foreach (array_keys($mbox_list) as $key) {
+            if ($GLOBALS['imp_search']->isSearchMbox($key)) {
+                foreach ($GLOBALS['imp_search']->getSearchFolders($key) as $skey) {
+                    $process_list[$skey] = $mbox_list[$key];
                 }
             } else {
-                $this->_impImap->changeMbox($val);
-                @imap_expunge($imp['stream']);
+                $process_list[$key] = $mbox_list[$key];
             }
         }
+
+        foreach ($process_list as $key => $val) {
+            $unflag = false;
+            $imp_imap->changeMbox($key);
+            if ($this->_usepop) {
+                $update_list[$key] = $val;
+                $msg_cache->deleteMsgs($key, $val);
+            } else {
+                $ids = @imap_search($stream, 'DELETED', SE_UID);
+                if (!empty($ids)) {
+                    if (is_array($val) && !empty($val)) {
+                        $unflag = array_diff($ids, $val);
+                        if (!empty($unflag)) {
+                            $unflag = implode(',', $unflag);
+                            @imap_clearflag_full($stream, $unflag, '\\DELETED', ST_UID);
+                        }
+                        $ids = $val;
+                    }
+                    $msg_cache->deleteMsgs($key, $ids);
+                    $update_list[$key] = $ids;
+                }
+            }
+            // Need to make sure we have a read-write mailbox since
+            // deleteMsgs() may switch to read-only access.
+            $imp_imap->changeMbox($key);
+            @imap_expunge($stream);
+            if ($unflag) {
+                @imap_setflag_full($stream, $unflag, '\\DELETED', ST_UID);
+            }
+        }
+
+        $this->_updateMailbox($update_list, 'expunge');
+
+        return $update_list;
     }
 
     /**
@@ -669,35 +766,104 @@ class IMP_Message {
      */
     function emptyMailbox($mbox_list)
     {
-        global $imp, $notification;
+        global $notification;
+
+        require_once IMP_BASE . '/lib/IMAP/Cache.php';
+        require_once IMP_BASE . '/lib/IMAP/MessageCache.php';
+        $imap_cache = &IMP_IMAP_Cache::singleton();
+        $msg_cache = &IMP_MessageCache::singleton();
+
+        $imp_imap = &IMP_IMAP::singleton();
+        $stream = $imp_imap->stream();
 
         foreach ($mbox_list as $mbox) {
             if ($GLOBALS['imp_search']->isVTrashFolder($mbox)) {
-                $this->expungeMailbox($GLOBALS['imp_search']->getSearchFolders($mbox));
+                $this->expungeMailbox(array_flip($GLOBALS['imp_search']->getSearchFolders($mbox)));
                 $notification->push(_("Emptied all messages from Virtual Trash Folder."), 'horde.success');
                 continue;
             }
 
             $display_mbox = IMP::displayFolder($mbox);
 
-            if (($this->_impImap->changeMbox($mbox)) !== true) {
+            if (!$imp_imap->changeMbox($mbox)) {
                 $notification->push(sprintf(_("Could not delete messages from %s. The server said: %s"), $display_mbox, imap_last_error()), 'horde.error');
                 continue;
             }
 
             /* Make sure there is at least 1 message before attempting to
                delete. */
-            $delete_array = array($mbox => array('1:*'));
-            if (!@imap_num_msg($imp['stream'])) {
+            if (!@imap_num_msg($stream)) {
                 $notification->push(sprintf(_("The mailbox %s is already empty."), $display_mbox), 'horde.message');
-            } elseif (!$this->delete($delete_array, true)) {
-                $notification->push(sprintf(_("There was a problem expunging the mailbox. The server said: %s"), imap_last_error()), 'horde.error');
-                continue;
             } else {
-                @imap_expunge($imp['stream']);
+                $trash_folder = ($GLOBALS['prefs']->getValue('use_trash')) ? IMP::folderPref($GLOBALS['prefs']->getValue('trash_folder'), true) : null;
+                if (empty($trash_folder) || ($trash_folder == $mbox)) {
+                    @imap_setflag_full($stream, '1:*', '\\DELETED');
+                    $this->expungeMailbox(array($mbox => 1));
+                } else {
+                    $indices = array($mbox => $imap_cache->getMailboxArrival($mbox, false));
+                    $this->delete($indices);
+                }
                 $notification->push(sprintf(_("Emptied all messages from %s."), $display_mbox), 'horde.success');
             }
         }
     }
 
+    /**
+     * Update the IMP_Mailbox object with mailbox changes.
+     *
+     * @access private
+     *
+     * @param array $msgList  The list of mailboxes/indices to update.
+     * @param string $action  The update action.
+     */
+    function _updateMailbox($msgList, $action)
+    {
+        require_once IMP_BASE . '/lib/Mailbox.php';
+
+        $mbox = false;
+        $mbox_actions = array(
+            'delete' => IMP_MAILBOX_DELETE,
+            'expunge' => IMP_MAILBOX_EXPUNGE,
+            'flag' => IMP_MAILBOX_FLAG
+        );
+
+        /* The IMP_Mailbox object, if it exists, can be either a regular or
+         * search mailbox. */
+        if (is_a($this->_mboxOb, 'IMP_Mailbox')) {
+            $this->_mboxOb->updateMailbox($mbox_actions[$action], $msgList);
+            $mbox = $this->_mboxOb->getMailboxName();
+        }
+
+        /* We already know that there are no search mailboxes in $msgList,
+         * only regular mailboxes. */
+        foreach ($msgList as $key => $val) {
+            if (!$mbox || ($mbox != $key)) {
+                $mbox_ob = &IMP_Mailbox::singleton($key);
+                $mbox_ob->updateMailbox($mbox_actions[$action], array($key => $val));
+            }
+        }
+    }
+
+    /**
+     * Obtains the size of a mailbox.
+     *
+     * @since IMP 4.2
+     *
+     * @param string $mbox_list   The mailbox to obtain the size of.
+     * @param boolean $formatted  Whether to return a human readable value.
+     */
+    function sizeMailbox($mbox, $formatted = true)
+    {
+        $imp_imap = &IMP_IMAP::singleton();
+        $imp_imap->changeMbox($mbox);
+        $info = @imap_mailboxmsginfo($imp_imap->stream());
+        if ($info) {
+            return ($formatted)
+                ? sprintf(_("%.2fMB"), $info->Size / (1024 * 1024))
+                : $info->Size;
+        } else {
+            return 0;
+        }
+    }
+
 }
