@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/message.php,v 2.560.4.58 2009/01/27 14:50:30 chuck Exp $
+ * $Horde: imp/message.php,v 2.560.4.62 2010-07-01 20:00:26 slusarz Exp $
  *
  * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
@@ -46,6 +46,7 @@ if (!$imp_mailbox->isValidIndex()) {
 }
 
 $flagged_unseen = false;
+$dnsnoprefetch = true;
 $printer_friendly = false;
 
 /* Set the current time zone. */
@@ -342,8 +343,8 @@ if (!empty($user_hdrs) && !$all_headers) {
  * stuff in the query string, so we need to do an add/remove of 'index'. */
 $selfURL = Util::removeParameter(Horde::selfUrl(true), array('index', 'actionID', 'mailbox', 'thismailbox'));
 $selfURL = IMP::generateIMPUrl($selfURL, $imp_mbox['mailbox'], $index, $mailbox_name);
-$selfURL = Util::addParameter($selfURL, 'message_token', $message_token);
-$headersURL = Util::removeParameter($selfURL, array('show_all_headers', 'show_list_headers'));
+$selfURL = html_entity_decode(Util::addParameter($selfURL, 'message_token', $message_token));
+$headersURL = htmlspecialchars(Util::removeParameter($selfURL, array('show_all_headers', 'show_list_headers')));
 
 /* Get the starting index for the current message and the message
  * count. */
@@ -502,7 +503,8 @@ if (!$printer_friendly) {
     $t_template->set('thismailbox', htmlspecialchars($mailbox_name));
     $t_template->set('start', htmlspecialchars($msgindex));
     $t_template->set('index', htmlspecialchars($index));
-    $t_template->set('label', sprintf(_("%s: %s (%d&nbsp;of&nbsp;%d)"), $header_label, $shortsub, $msgindex, $msgcount));
+    $t_template->set('label', sprintf(_("%s: %s"), $header_label, $shortsub));
+    $t_template->set('msg_count', sprintf(_("(%d&nbsp;of&nbsp;%d)"), $msgindex, $msgcount));
     $t_template->set('status', $status);
     $t_template->set('message_token', $message_token);
 
@@ -617,13 +619,13 @@ if (!$printer_friendly) {
 
     $a_template->set('headers', Horde::widget('#', _("Headers"), 'widget hasmenu', '', '', _("Headers"), true));
     if ($all_headers || $list_headers) {
-        $a_template->set('common_headers', Horde::widget(htmlspecialchars($headersURL), _("Show Common Headers"), 'widget', '', '', _("Show Common Headers"), true));
+        $a_template->set('common_headers', Horde::widget($headersURL, _("Show Common Headers"), 'widget', '', '', _("Show Common Headers"), true));
     }
     if (!$all_headers) {
-        $a_template->set('all_headers', Horde::widget(htmlspecialchars(Util::addParameter($headersURL, 'show_all_headers', 1)), _("Show All Headers"), 'widget', '', '', _("Show All Headers"), true));
+        $a_template->set('all_headers', Horde::widget(Util::addParameter($headersURL, 'show_all_headers', 1), _("Show All Headers"), 'widget', '', '', _("Show All Headers"), true));
     }
     if ($list_info['exists'] && !$list_headers) {
-        $a_template->set('list_headers', Horde::widget(htmlspecialchars(Util::addParameter($headersURL, 'show_list_headers', 1)), _("Show Mailing List Information"), 'widget', '', '', _("Show Mailing List Information"), true));
+        $a_template->set('list_headers', Horde::widget(Util::addParameter($headersURL, 'show_list_headers', 1), _("Show Mailing List Information"), 'widget', '', '', _("Show Mailing List Information"), true));
     }
 
     echo $a_template->fetch(IMP_TEMPLATES . '/message/navbar_actions.html');
@@ -678,9 +680,8 @@ if ($show_parts || ($downloadall_link && !$printer_friendly)) {
     if ($downloadall_link && !$printer_friendly) {
         $val .= Horde::link($downloadall_link, _("Download All Attachments (in .zip file)")) . _("Download All Attachments (in .zip file)") . ' ' . Horde::img('compressed.png', _("Download All Attachments (in .zip file)"), '', $registry->getImageDir('horde') . '/mime') . '</a>';
         if ($prefs->getValue('strip_attachments')) {
-            $url = Horde::selfUrl(true);
-            $url = Util::removeParameter($url, array('actionID'));
-            $url = Util::addParameter($url, array('actionID' => 'strip_all', 'message_token' => $message_token));
+            $url = Util::removeParameter(Horde::selfUrl(true), array('actionID'));
+            $url = html_entity_decode(Util::addParameter($url, array('actionID' => 'strip_all', 'message_token' => $message_token)));
             $val .= '<br />' . Horde::link(htmlspecialchars($url), _("Strip All Attachments"), null, null, "return window.confirm('" . addslashes(_("Are you sure you wish to PERMANENTLY delete all attachments?")) . "');") . _("Strip All Attachments") . ' ' . Horde::img('delete.png', _("Strip Attachments"), null, $registry->getImageDir('horde')) . '</a>';
         }
     }
